@@ -9,6 +9,7 @@ import testConsistency from './test-consistency.js';
 import testDescriptions from './test-descriptions.js';
 import testFilename from './test-filename.js';
 import testLinks from './test-links.js';
+import testMirror from './test-mirror.js';
 import testMultipleStatements from './test-multiple-statements.js';
 import testNotes from './test-notes.js';
 import testObsolete from './test-obsolete.js';
@@ -26,6 +27,7 @@ export default new Linters([
   testDescriptions,
   testFilename,
   testLinks,
+  testMirror,
   testMultipleStatements,
   testNotes,
   testObsolete,
